/**
	******************************************************************************
	* @file    LedAlarms.c
	* @author  Healthcare (MIC) team
	* @brief   Led Alarms API Implementation. These APIs are used for indicating 
	*          status to user
	******************************************************************************
	* @attention
	*
	*     Copyright 2016, GE Healthcare.
	*
	*
	*     This Program is an unpublished work that is fully protected
	*     by the United States Copyright Laws and is fully considered
	*     to be a TRADE SECRET belonging to GE Healthcare.
	*
	*     This document shall not be copied, in whole or in part, nor
	*     shall the algorithms or code defined within this document be
	*     disclosed to others without the express written permission
	*     of GE Healthcare.
	*
	******************************************************************************
**/
/**
	* History:
	*
	*  Revision        Description
	*
	*  
	*
	******************************************************************************
**/
/* Define to prevent recursive inclusion */
#ifndef __LEDALARMS_H
#define __LEDALARMS_H

/* Includes ------------------------------------------------------------------*/
#include "stm32f4xx_hal_gpio.h"
#include "stm32f4xx_hal.h"

/* Exported types ------------------------------------------------------------*/
typedef enum 
{
  LED1 = 0,
  LED2 = 1,
  LED3 = 2,
  LED4 = 3
}AlarmLed_TypeDef;

/* Exported macro ------------------------------------------------------------*/
#define LEDn                             4
#define LED1_PIN                         GPIO_PIN_6
#define LED1_GPIO_PORT                   GPIOG
#define LED1_GPIO_CLK_ENABLE()           __GPIOG_CLK_ENABLE()  
#define LED1_GPIO_CLK_DISABLE()          __GPIOG_CLK_DISABLE()  
    
    
#define LED2_PIN                         GPIO_PIN_7
#define LED2_GPIO_PORT                   GPIOG
#define LED2_GPIO_CLK_ENABLE()           __GPIOG_CLK_ENABLE()   
#define LED2_GPIO_CLK_DISABLE()          __GPIOG_CLK_DISABLE()  
  
#define LED3_PIN                         GPIO_PIN_10
#define LED3_GPIO_PORT                   GPIOG
#define LED3_GPIO_CLK_ENABLE()           __GPIOG_CLK_ENABLE()   
#define LED3_GPIO_CLK_DISABLE()          __GPIOG_CLK_DISABLE()  
  
#define LED4_PIN                         GPIO_PIN_12
#define LED4_GPIO_PORT                   GPIOG
#define LED4_GPIO_CLK_ENABLE()           __GPIOG_CLK_ENABLE()   
#define LED4_GPIO_CLK_DISABLE()          __GPIOG_CLK_DISABLE()  
    
#define LEDx_GPIO_CLK_ENABLE(__INDEX__)  do{if((__INDEX__) == 0) LED1_GPIO_CLK_ENABLE(); else \
                                            if((__INDEX__) == 1) LED2_GPIO_CLK_ENABLE(); else \
                                            if((__INDEX__) == 2) LED3_GPIO_CLK_ENABLE(); else \
                                            if((__INDEX__) == 3) LED4_GPIO_CLK_ENABLE(); \
                                            }while(0)

#define LEDx_GPIO_CLK_DISABLE(__INDEX__)  do{if((__INDEX__) == 0) LED1_GPIO_CLK_DISABLE(); else \
                                             if((__INDEX__) == 1) LED2_GPIO_CLK_DISABLE(); else \
                                             if((__INDEX__) == 2) LED3_GPIO_CLK_DISABLE(); else \
                                             if((__INDEX__) == 3) LED4_GPIO_CLK_DISABLE(); \
                                             }while(0)

/* Exported functions ------------------------------------------------------- */
extern void AlarmLEDTurnOff (AlarmLed_TypeDef);
extern void AlarmLEDTurnOn (AlarmLed_TypeDef);
extern void AlarmNotifiy (AlarmLed_TypeDef, int);;
extern void AlarmLEDIntiallize (void);


#endif /* __LEDALARMS_H */

