/**
	******************************************************************************
	* @file    LedAlarms.c
	* @author  Healthcare (MIC) team
	* @brief   Led Alarms API Implementation. These APIs are used for indicating 
	*          status to user
	******************************************************************************
	* @attention
	*
	*     Copyright 2016, GE Healthcare.
	*
	*
	*     This Program is an unpublished work that is fully protected
	*     by the United States Copyright Laws and is fully considered
	*     to be a TRADE SECRET belonging to GE Healthcare.
	*
	*     This document shall not be copied, in whole or in part, nor
	*     shall the algorithms or code defined within this document be
	*     disclosed to others without the express written permission
	*     of GE Healthcare.
	*
	******************************************************************************
**/
/**
	* History:
	*
	*  Revision        Description
	*
	*  
	*
	******************************************************************************
**/
/* Define to prevent recursive inclusion */
#ifndef __LEDALARMS_H
#define __LEDALARMS_H

/* Includes ------------------------------------------------------------------*/
#include "main.h"
//#include "typedef.h"

/* Exported types ------------------------------------------------------------*/
typedef enum 
{
    WHITE_LED = 0,
    RED_LED = 1,
    YELLOW_LED = 2
}AlarmLed_TypeDef;

/* Exported macro ------------------------------------------------------------*/

#define LEDn                             3

#define WHITE_LED_PIN                         GPIO_PIN_6
#define WHITE_LED_GPIO_PORT                   GPIOG
#define WHITE_LED_GPIO_CLK_ENABLE()           __GPIOG_CLK_ENABLE()  
#define WHITE_LED_GPIO_CLK_DISABLE()          __GPIOG_CLK_DISABLE()  
       
#define RED_LED_PIN                         GPIO_PIN_7
#define RED_LED_GPIO_PORT                   GPIOG
#define RED_LED_GPIO_CLK_ENABLE()           __GPIOG_CLK_ENABLE()   
#define RED_LED_GPIO_CLK_DISABLE()          __GPIOG_CLK_DISABLE()  
  
#define YELLOW_LED_PIN                         GPIO_PIN_10
#define YELLOW_LED_GPIO_PORT                   GPIOG
#define YELLOW_LED_GPIO_CLK_ENABLE()           __GPIOG_CLK_ENABLE()   
#define YELLOW_LED_GPIO_CLK_DISABLE()          __GPIOG_CLK_DISABLE() 

#define LED4_PIN                         GPIO_PIN_12
#define LED4_GPIO_PORT                   GPIOG
#define LED4_GPIO_CLK_ENABLE()           __GPIOG_CLK_ENABLE()   
#define LED4_GPIO_CLK_DISABLE()          __GPIOG_CLK_DISABLE()
   
#define LEDx_GPIO_CLK_ENABLE(__INDEX__)  do{if((__INDEX__) == 0) WHITE_LED_GPIO_CLK_ENABLE(); else \
                                            if((__INDEX__) == 1) RED_LED_GPIO_CLK_ENABLE(); else \
                                            if((__INDEX__) == 2) YELLOW_LED_GPIO_CLK_ENABLE(); else \
											if((__INDEX__) == 3) LED4_GPIO_CLK_ENABLE(); \
                                            }while(0)

#define LEDx_GPIO_CLK_DISABLE(__INDEX__)  do{if((__INDEX__) == 0) WHITE_LED_GPIO_CLK_DISABLE(); else \
                                             if((__INDEX__) == 1) RED_LED_GPIO_CLK_DISABLE(); else \
                                             if((__INDEX__) == 2) YELLOW_LED_GPIO_CLK_DISABLE();else \
											 if((__INDEX__) == 3) LED4_GPIO_CLK_DISABLE(); \
                                             }while(0)


/** 1 seconds delay */											 
#define DEFAULT_DELAY_MS    1000  
											 
/* Exported functions ------------------------------------------------------- */

extern void AlarmLEDTurnOff (AlarmLed_TypeDef);
extern void AlarmLEDTurnOn (AlarmLed_TypeDef);
extern int AlarmNotifiy (AlarmLed_TypeDef, float);
extern void AlarmLEDInitialize (void);
extern void AlarmLEDUninitialize (void); 
extern void AlarmLEDToggle (AlarmLed_TypeDef);
											 
void AlarmRedLEDBlink(AlarmLed_TypeDef LED, float frequency);
												 
int AlarmTimerConfigure(void);
void AlarmRedLEDBlink(AlarmLed_TypeDef LED, float frequency);
int AlarmNotifiyTurnOFF(AlarmLed_TypeDef LED) ;

#endif /* __LEDALARMS_H */

