/**
	******************************************************************************
	* @file    LedAlarms.c
	* @author  Healthcare (MIC) team
	* @brief   Led Alarms API Implementation. These APIs are used for indicating 
	*          status to user
	******************************************************************************
	* @attention
	*
	*     Copyright 2016, GE Healthcare.
	*
	*
	*     This Program is an unpublished work that is fully protected
	*     by the United States Copyright Laws and is fully considered
	*     to be a TRADE SECRET belonging to GE Healthcare.
	*
	*     This document shall not be copied, in whole or in part, nor
	*     shall the algorithms or code defined within this document be
	*     disclosed to others without the express written permission
	*     of GE Healthcare.
	*
	******************************************************************************
**/
/**
	* History:
	*
	*  Revision        Description
	*
	*  
	*
	******************************************************************************
**/
/** Include files */
#include "LedAlarms.h"
//#define DEBUG_LOG
/* Private variables ---------------------------------------------------------*/
static const uint16_t GPIO_PIN[LEDn] = {WHITE_LED_PIN,
                                        RED_LED_PIN,
                                        YELLOW_LED_PIN};

static GPIO_TypeDef* GPIO_PORT[LEDn] = {WHITE_LED_GPIO_PORT,
                                        RED_LED_GPIO_PORT,
                                        YELLOW_LED_GPIO_PORT};

/* Timer handler declaration */
TIM_HandleTypeDef  TimHandle;
uint8_t LED_LIST[3] ={0};
uint32_t LED_FREQ[3] ={0};
/**
    * \fn        : AlarmNotifiy (void)
    * \brief     : Alarm LED's in desired frequency    
    * \param[in] :  @arg  WHITE_LED
    *               @arg  RED_LED
    *               @arg  YELLOW_LED
    * \param[in] :  frequency
    * \return    : NA
    * Dependencies: NA
    * Unusual Features: NA
*/
int AlarmNotifiy(AlarmLed_TypeDef LED, float frequency)
{
	AlarmTimerConfigure();
	LED_LIST[LED] = 0xFF;  
	LED_FREQ[LED] = frequency;  
}

int AlarmNotifiyTurnOFF(AlarmLed_TypeDef LED)
{
	LED_LIST[LED] = NULL;  
	LED_FREQ[LED] = NULL;
	AlarmLEDTurnOff(LED);
}

/**
    * \fn        : AlarmTimerConfigure (void)
    * \brief     : Alarm LED's in desired frequency    
    * \param[in] :  @arg  WHITE_LED
    *               @arg  RED_LED
    *               @arg  YELLOW_LED
    * \param[in] :  frequency
    * \return    : NA
    * Dependencies: NA
    * Unusual Features: NA
*/
int AlarmTimerConfigure(void)
{

	uint32_t u32PrescalerValue = 0;
  int eStatus = SUCCESS;

  
	u32PrescalerValue = (uint32_t) ((SystemCoreClock /2) / 10000) - 1;
	/* Set TIMx instance */
	if ( HAL_TIM_Base_GetState(&TimHandle) == HAL_TIM_STATE_RESET)
	{
		TimHandle.Instance = TIM3;
		/* Initialize TIM3 peripheral as follows:
		+ Period = 10000 - 1
		+ Prescaler = ((SystemCoreClock/2)/10000) - 1
		+ ClockDivision = 0
		+ Counter direction = Up
		*/
		TimHandle.Init.Period = 5000 -1;   // 0.5sec
		TimHandle.Init.Prescaler = u32PrescalerValue;
		TimHandle.Init.ClockDivision = TIM_CR1_CKD_0;
		TimHandle.Init.CounterMode = TIM_COUNTERMODE_UP;
		
		if(HAL_TIM_Base_Init(&TimHandle) == HAL_OK)
		{
			/*##-2- Start the TIM Base generation in interrupt mode ####################*/
			if(HAL_TIM_Base_Start_IT(&TimHandle) == HAL_OK)
			{
			 	printf("failed\n");
			 	eStatus = SUCCESS;
			}			
		}
	}
    return eStatus;  
}
/**
    * \fn        : AlarmLEDIntiallize (void)
    * \brief     : The function initializes the I/O pins required for addressing the LEDs 
    * \param[in] : none
    * \return    : NA
    * Dependencies: NA
    * Unusual Features: NA
*/
void AlarmLEDInitialize(void)
{
	
	GPIO_InitTypeDef  GPIO_InitStruct;
	
	/* Enable the GPIO_LED clock */
	LEDx_GPIO_CLK_ENABLE(0);
	LEDx_GPIO_CLK_ENABLE(1);
	LEDx_GPIO_CLK_ENABLE(2);
	LEDx_GPIO_CLK_ENABLE(3);

	/* Configure the GPIO_LED pin */
	GPIO_InitStruct.Pin =  WHITE_LED_PIN | RED_LED_PIN | YELLOW_LED_PIN | LED4_PIN;
	GPIO_InitStruct.Mode = GPIO_MODE_OUTPUT_PP;
	GPIO_InitStruct.Pull = GPIO_PULLUP;
	GPIO_InitStruct.Speed = GPIO_SPEED_FAST;
	HAL_GPIO_Init(GPIOG, &GPIO_InitStruct); 
	HAL_GPIO_WritePin(GPIOG, WHITE_LED_PIN | YELLOW_LED_PIN | RED_LED_PIN | LED4_PIN ,GPIO_PIN_SET);
	HAL_GPIO_LockPin(GPIOG, GPIO_PIN_6);
	
}

/**
    * \fn        : AlarmLEDUninitialize (void)
    * \brief     : The function de-initializes the I/O pins used for addressing the LEDs   
    * \param[in] : none
    * \return    : NA
    * Dependencies: NA
    * Unusual Features: NA
*/
void AlarmLEDUninitialize (void) 
{

  HAL_GPIO_DeInit(GPIOB, WHITE_LED_PIN | RED_LED_PIN );
  HAL_GPIO_DeInit(GPIOA, YELLOW_LED_PIN);

}


/**
    * \fn        : AlarmLEDTurnOn (void)
    * \brief     : Turns selected LED On
    * \param[in] :  @arg  WHITE_LED
    *               @arg  RED_LED
    *               @arg  YELLOW_LED
    * \return    : NA        
    * Dependencies: NA
    * Unusual Features: NA
*/
void AlarmLEDTurnOn(AlarmLed_TypeDef Led)
{
  HAL_GPIO_WritePin(GPIO_PORT[Led], GPIO_PIN[Led], GPIO_PIN_RESET);
}

/**
    * \fn        : AlarmLEDTurnOff (void)
    * \brief     : Turns selected LED off
    * \param[in] :  @arg  WHITE_LED
    *               @arg  RED_LED
    *               @arg  YELLOW_LED
    * \return    : NA        
    * Dependencies: NA
    * Unusual Features: NA
*/
void AlarmLEDTurnOff(AlarmLed_TypeDef Led)
{
  if(HAL_TIM_Base_Stop_IT(&TimHandle) != HAL_OK)
  {
			printf("failed\n");
  }
  HAL_GPIO_WritePin(GPIO_PORT[Led], GPIO_PIN[Led], GPIO_PIN_SET); 
}

/**
  * \fn        : AlarmLEDTurnOff (void)
  * @brief  Toggles the selected LED.
    * \param[in] :  Led: LED to be toggled
	*               @arg  WHITE_LED
    *               @arg  RED_LED
    *               @arg  YELLOW_LED
    * \return    : NA        
    * Dependencies: NA
    * Unusual Features: NA
  */
void AlarmLEDToggle(AlarmLed_TypeDef Led)
{
	HAL_GPIO_TogglePin(GPIO_PORT[Led], GPIO_PIN[Led]);
}

/**
  * @brief  Period elapsed callback in non blocking mode
  * @param  htim: TIM handle
  * @retval None
  */
void HAL_TIM_PeriodElapsedCallback(TIM_HandleTypeDef *htim)
{

		uint8_t index;
		static uint32_t Redcount = 0;
		static uint32_t Whitecount = 0;
		static uint32_t Greencount = 0;
		//if (TIM_GetITStatus (TIM3, TIM_IT_Update) != RESET) 
		//{
		Greencount++;
		Whitecount++;
		Redcount++;
		if (Redcount >= 2) 
		{
			for (index=0;index<3;index++)
			{
				 if(LED_LIST[index] == 0XFF && (LED_FREQ[index] == 2))
				 {
						AlarmLEDToggle(index);
				 }
			}
		Redcount = 0;
		}
		if (Whitecount >= 3) 
		{
		for (index=0;index<3;index++)
		{
			 if(LED_LIST[index] == 0XFF && (LED_FREQ[index] == 3))
			 {
					AlarmLEDToggle(index);
			 }
		}
		Whitecount = 0 ;
		}
		if (Greencount >= 4)
		{
		for (index=0;index<3;index++)
		{
			 if(LED_LIST[index] == 0XFF && (LED_FREQ[index] == 4))
			 {
					AlarmLEDToggle(index);
			 }
		}
		Greencount = 0;
		}
		//__HAL_TIM_CLEAR_IT(htim,TIM_IT_TRIGGER);
	  //}
}


