/**
  ******************************************************************************
  * @file    FMC_SDRAM/Src/main.c
  * @author  Healthcare Team
  * @date    08-March-2017
  * @brief   Configuring and usage of GPIOs through the STM32F4xx HAL API.
  **/

/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "uart.h"

#ifdef _RTE_
#include "RTE_Components.h"             // Component selection
#endif

extern ARM_DRIVER_USART  Driver_USART1;
ARM_DRIVER_USART    *uart = &Driver_USART1;

/********************************************************************************	
	* @brief  callback function for Driver_UART0
  * @param  None
  * @retval None		
********************************************************************************/	
void print(const char *str)
{
  int len;
  int r;
 
  /* strlen() */
  for (len = 0; str[len] != '\0'; len++) {
    /* DO NOTHING */
  }
  while (len > 0) {
    r = uart->Send((const uint8_t *)str, len);
    if (r < 0) {
      return; /* error */
    } else {
      str += r;
      len -= r;
    }
  }
} 
/********************************************************************************  
  * @brief  Retargets the C library printf function to the USART
  * @param  None
  * @retval None    
********************************************************************************/ 
int stdout_putchar(int ch)
{
	uart->Send((uint8_t *)&ch, 1);
	//HAL_Delay(10);
  return ch;
}

/********************************************************************************  
  * @brief  Retargets the C library scanf function to the USART
  * @param  None
  * @retval None    
********************************************************************************/
int stdin_getchar (void)
{
	char buff;
	int ret;
	ret = uart->Receive(&buff, 1);
	if( ret == ARM_DRIVER_OK)
	{
		return buff;
	}
	return NULL;
}

/********************************************************************************  
  * @brief  CMSIS USART driver event callback Handler
  * @param  None
  * @retval None    
********************************************************************************/
void USART_callback(uint32_t event)
{
    switch (event)
    {
    case ARM_USART_EVENT_RECEIVE_COMPLETE:    
    case ARM_USART_EVENT_TRANSFER_COMPLETE:
    case ARM_USART_EVENT_SEND_COMPLETE:
    case ARM_USART_EVENT_TX_COMPLETE:
        /* Success: Wakeup Thread */
        break;
 
    case ARM_USART_EVENT_RX_TIMEOUT:
        // __breakpoint(0);  /* Error: Call debugger or replace with custom error handling */
        break;
 
    case ARM_USART_EVENT_RX_OVERFLOW:
			  //  __breakpoint(0);  /* Error: Call debugger or replace with custom error handling */
        break;
    case ARM_USART_EVENT_TX_UNDERFLOW:
        __breakpoint(0);  /* Error: Call debugger or replace with custom error handling */
        break;
    }
}  
/********************************************************************************  
  * @brief  CMSIS USART driver Intiallization
  * @param  None
  * @retval None    
********************************************************************************/
void configureUART()
{
  static ARM_DRIVER_USART * USARTdrv = &Driver_USART1;
  #ifdef DEBUG
    version = USARTdrv->GetVersion();
    if (version.api < 0x200)   /* requires at minimum API version 2.00 or higher */
    {                          /* error handling */
        return;
    }
    drv_capabilities = USARTdrv->GetCapabilities();
    if (drv_capabilities.event_tx_complete == 0)
    {                          /* error handling */
        return;
    }
  #endif
 
    /*Initialize the USART driver */
    USARTdrv->Initialize(USART_callback);
    /*Power up the USART peripheral */
    USARTdrv->PowerControl(ARM_POWER_FULL);
    /*Configure the USART to 115200 Bits/sec */
    USARTdrv->Control(ARM_USART_MODE_ASYNCHRONOUS |
                      ARM_USART_DATA_BITS_8 |
                      ARM_USART_PARITY_NONE |
                      ARM_USART_STOP_BITS_1 |
                      ARM_USART_FLOW_CONTROL_NONE, 115200);
     
    /* Enable Receiver and Transmitter lines */
    USARTdrv->Control (ARM_USART_CONTROL_TX, 1);
    USARTdrv->Control (ARM_USART_CONTROL_RX, 1);
    print("Uart driver intiallized \n\r");
}
